cis_config: comm_t Struct Reference

cis_config

Public Attributes | List of all members
comm_t Struct Reference

Communication structure. More...

`#include <CommBase.h>`

## Public Attributes
comm_type | type
| Comm type.
char | name [COMM_NAME_SIZE]
| Comm name.
char | address [COMM_ADDRESS_SIZE]
| Comm address.
char | direction [COMM_DIR_SIZE]
| send or recv for direction messages will go.
int | valid
| 1 if communicator initialized, 0 otherwise.
void * | handle
| Pointer to handle for comm.
void * | info
| Pointer to any extra info comm requires.
seri_t * | serializer
| Serializer for comm messages.
size_t | maxMsgSize
| The maximum message size.
int | always_send_header
| 1 if comm should always send a header.
int | index_in_register
| Index of the comm in the comm register.
time_t * | last_send
| Clock output at time of last send.
int * | sent_eof
| Flag specifying if EOF has been sent.
int * | recv_eof
| Flag specifying if EOF has been received.
int * | used
| Flag specifying if the comm has been used.
void * | reply
| Reply information.
int | is_file
| Flag specifying if the comm connects directly to a file.
int | is_work_comm
| Flag specifying if comm is a temporary work comm.

## Detailed Description

Communication structure.

The documentation for this struct was generated from the following file:

- /root/cis_interface/cis_interface/cis_interface/communication/CommBase.h